@@ -8,18 +8,23 @@ acovu<-array(0,c(ndim,ndim,nr))
 gdx<-gs$dx
 
 for (i in 1:nr) {
-	gdxi<-gdx[i,,]
+        gdxi <- rbind(gdx[i,,])
+        
+        #gdxi<-gdx[i,,]
 	gdxs<-drop(gdxi%*%prop)
-	acovu[,,i]<-(gdxi%*%(prop*t(gdxi))-outer(gdxs,gdxs))/N
+     
+        acovu[,,i]<-(gdxi%*%(prop*t(gdxi))-outer(gdxs,gdxs))/N
 	}
 
 acovv<-array(0,c(ndim,ndim,nc))
 gdz<-gs$dz
 
 for (i in 1:nc) {
-	gdzi<-gdz[i,,]
-	gdzs<-drop(gdzi%*%prop)
+	gdzi<- rbind(gdz[i,,])
+        
+        #gdzi<-gdz[i,,]
+        gdzs<-drop(gdzi%*%prop)
 	acovv[,,i]<-(gdzi%*%(prop*t(gdzi))-outer(gdzs,gdzs))/N
 	}
 return(list(acovd=acovd,acovu=acovu,acovv=acovv))
-}
\ No newline at end of file
+}
